@@ -42,6 +42,20 @@ def set_api(url):
     '''
     global api
     api = url
+
+
+def set_session(session_to_be_set):
+    '''Set the session for access to the API.
+    
+    This method enables a session that has been authenticated
+    by means outside this module to be used for API interactions.
+    
+    Parameters:
+      * session_to_be_set: the requests session to be used for
+      interactions with the system's API.
+    '''
+    global session
+    session = session_to_be_set
     
     
 def query(constraints, credential_and_key=None):
